@@ -7,11 +7,13 @@ from scipy.interpolate import interp1d
 from astropy.table import Table
 
 from .helpers import _get_x_in_wavenumbers, _test_valid_x_range
-from .baseclasses import BaseExtAveModel
-from .shapes import P92, _curve_F99_method
+from .baseclasses import BaseExtModel
+from .shapes import P92, G21, _curve_F99_method
 
 __all__ = [
     "RL85_MWGC",
+    "RRP89_MWGC",
+    "B92_MWAvg",
     "G03_SMCBar",
     "G03_LMCAvg",
     "G03_LMC2",
@@ -20,10 +22,11 @@ __all__ = [
     "CT06_MWLoc",
     "GCC09_MWAvg",
     "F11_MWGC",
+    "G21_MWAvg",
 ]
 
 
-class RL85_MWGC(BaseExtAveModel):
+class RL85_MWGC(BaseExtModel):
     r"""
     Reike & Lebofsky (1985) MW Average Extinction Curve
 
@@ -88,7 +91,7 @@ class RL85_MWGC(BaseExtAveModel):
     obsdata_tolerance = 1e-6
 
     def evaluate(self, in_x):
-        """
+        r"""
         RL85 MWGC function
 
         Parameters
@@ -121,7 +124,208 @@ class RL85_MWGC(BaseExtAveModel):
         return f(x)
 
 
-class G03_SMCBar(BaseExtAveModel):
+class RRP89_MWGC(BaseExtModel):
+    r"""
+    Reike, Rieke, & Paul (1989) MW Average Extinction Curve
+
+    Parameters
+    ----------
+    None
+
+    Raises
+    ------
+    None
+
+    Notes
+    -----
+    From Rieke, Rieke, & Paul (1989, ApJ, 336, 752)
+
+    Example showing the average curve
+
+    .. plot::
+        :include-source:
+
+        import numpy as np
+        import matplotlib.pyplot as plt
+        import astropy.units as u
+
+        from dust_extinction.averages import RRP89_MWGC
+
+        fig, ax = plt.subplots()
+
+        # define the extinction model
+        ext_model = RRP89_MWGC()
+
+        # generate the curves and plot them
+        x = np.arange(1.0/ext_model.x_range[1], 1.0/ext_model.x_range[0], 0.1) * u.micron
+
+        ax.plot(x,ext_model(x),label='RRP89_MWGC')
+        ax.plot(1.0/ext_model.obsdata_x, ext_model.obsdata_axav, 'ko',
+                label='obsdata')
+
+        ax.set_xlabel(r'$\lambda$ [$\mu m$]')
+        ax.set_ylabel(r'$A(x)/A(V)$')
+
+        ax.legend(loc='best')
+        plt.show()
+    """
+
+    x_range = [1.0 / 13.0, 1.0 / 0.90]
+
+    Rv = 3.09
+
+    # fmt: off
+    obsdata_x = 1.0 / np.array(
+        [0.90, 1.25, 1.6, 2.2, 3.5, 4.8, 8.0,
+         9.5, 10.6, 11.0, 13.0]
+    )
+    obsdata_elvebv = np.array(
+        [-1.60, -2.22, -2.55, -2.744, -2.88, -2.99, -3.01,
+         -2.73, -2.87, -2.84, -2.98]
+    )
+    # fmt: on
+    obsdata_axav = obsdata_elvebv / Rv + 1.0
+
+    # accuracy of the observed data based on published table
+    obsdata_tolerance = 1e-6
+
+    def evaluate(self, in_x):
+        r"""
+        RRP89 MWGC function
+
+        Parameters
+        ----------
+        in_x: float
+           expects either x in units of wavelengths or frequency
+           or assumes wavelengths in wavenumbers [1/micron]
+
+           internally wavenumbers are used
+
+        Returns
+        -------
+        axav: np array (float)
+            A(x)/A(V) extinction curve [mag]
+
+        Raises
+        ------
+        ValueError
+           Input x values outside of defined range
+        """
+        x = _get_x_in_wavenumbers(in_x)
+
+        # check that the wavenumbers are within the defined range
+        _test_valid_x_range(x, self.x_range, self.__class__.__name__)
+
+        # define the function using simple linear interpolation
+        # avoids negative values of alav that happens with cubic splines
+        f = interp1d(self.obsdata_x, self.obsdata_axav)
+
+        return f(x)
+
+
+class B92_MWAvg(BaseExtModel):
+    r"""
+    Bastiaansen (1992) Optical Extinction Curve
+
+    Parameters
+    ----------
+    None
+
+    Raises
+    ------
+    None
+
+    Notes
+    -----
+    From Bastiaansen (1992, A&AS, 93, 449-462)
+
+    Example showing the average curve
+
+    .. plot::
+        :include-source:
+
+        import numpy as np
+        import matplotlib.pyplot as plt
+        import astropy.units as u
+
+        from dust_extinction.averages import B92_MWAvg
+
+        fig, ax = plt.subplots()
+
+        # define the extinction model
+        ext_model = B92_MWAvg()
+
+        # generate the curves and plot them
+        x = np.arange(1.0/ext_model.x_range[1], 1.0/ext_model.x_range[0], 0.1) * u.micron
+
+        ax.plot(x,ext_model(x),label='B1992')
+        ax.plot(1.0/ext_model.obsdata_x, ext_model.obsdata_axav, 'ko',
+                label='obsdata')
+
+        ax.set_xlabel(r'$\lambda$ [$\mu m$]')
+        ax.set_ylabel(r'$A(x)/A(V)$')
+
+        ax.legend(loc='best')
+        plt.show()
+    """
+
+    x_range = [1.0 / 0.7873, 1.0 / 0.3402]
+
+    Rv = 3.1  # assumed!
+
+    # fmt: off
+    obsdata_x = 1.0 / np.array(
+        [0.7873, 0.7505, 0.7102, 0.6681, 0.64,
+         0.6107, 0.5821, 0.5601, 0.5407, 0.5205,
+         0.4999, 0.4708, 0.4496, 0.4395, 0.4192,
+         0.4038, 0.3785, 0.36, 0.3493, 0.3402]
+    )
+    obsdata_axav = np.array(
+        [0.849, 0.891, 0.941, 0.998, 1.045, 1.088,
+         1.139, 1.176, 1.226, 1.279, 1.34 , 1.418,
+         1.473, 1.507, 1.556, 1.595, 1.659, 1.718,
+         1.761, 1.795]
+    )
+    # fmt: on
+
+    # accuracy of the observed data based on published table
+    obsdata_tolerance = 6e-3
+
+    def evaluate(self, in_x):
+        """
+        B1992 function
+
+        Parameters
+        ----------
+        in_x: float
+           expects either x in units of wavelengths or frequency
+           or assumes wavelengths in wavenumbers [1/micron]
+
+           internally wavenumbers are used
+
+        Returns
+        -------
+        axav: np array (float)
+            A(x)/A(V) extinction curve [mag]
+
+        Raises
+        ------
+        ValueError
+           Input x values outside of defined range
+        """
+
+        x = _get_x_in_wavenumbers(in_x)
+
+        # check that the wavenumbers are within the defined range
+        _test_valid_x_range(x, self.x_range, self.__class__.name)
+
+        # define the function allowing for spline interpolation
+        f = interp1d(self.obsdata_x, self.obsdata_axav)
+
+        return f(x)
+
+
+class G03_SMCBar(BaseExtModel):
     r"""
     Gordon et al (2003) SMCBar Average Extinction Curve
 
@@ -246,7 +450,7 @@ class G03_SMCBar(BaseExtAveModel):
         )
 
 
-class G03_LMCAvg(BaseExtAveModel):
+class G03_LMCAvg(BaseExtModel):
     r"""
     Gordon et al (2003) LMCAvg Average Extinction Curve
 
@@ -365,7 +569,7 @@ class G03_LMCAvg(BaseExtAveModel):
         )
 
 
-class G03_LMC2(BaseExtAveModel):
+class G03_LMC2(BaseExtModel):
     r"""
     Gordon et al (2003) LMC2 Average Extinction Curve
 
@@ -487,7 +691,7 @@ class G03_LMC2(BaseExtAveModel):
         )
 
 
-class I05_MWAvg(BaseExtAveModel):
+class I05_MWAvg(BaseExtModel):
     r"""
     Indebetouw et al (2005) MW Average Extinction Curve
 
@@ -586,7 +790,7 @@ class I05_MWAvg(BaseExtAveModel):
         return f(x)
 
 
-class CT06_MWGC(BaseExtAveModel):
+class CT06_MWGC(BaseExtModel):
     r"""
     Chiar & Tielens (2006) MW Galactic Center Curve
 
@@ -688,7 +892,7 @@ class CT06_MWGC(BaseExtAveModel):
         return f(x)
 
 
-class CT06_MWLoc(BaseExtAveModel):
+class CT06_MWLoc(BaseExtModel):
     r"""
     Chiar & Tielens (2006) MW Local ISM Curve
 
@@ -790,7 +994,7 @@ class CT06_MWLoc(BaseExtAveModel):
         return f(x)
 
 
-class GCC09_MWAvg(BaseExtAveModel):
+class GCC09_MWAvg(BaseExtModel):
     r"""
     Gordon, Cartledge, & Clayton (2009) Milky Way Average Extinction Curve
 
@@ -954,7 +1158,7 @@ class GCC09_MWAvg(BaseExtAveModel):
         return p92_fit(in_x)
 
 
-class F11_MWGC(BaseExtAveModel):
+class F11_MWGC(BaseExtModel):
     r"""
     Fritz et al (2011) MW Galactic Center Curve
 
@@ -1056,3 +1260,142 @@ class F11_MWGC(BaseExtAveModel):
         f = interp1d(self.obsdata_x, self.obsdata_axav)
 
         return f(x)
+
+
+class G21_MWAvg(BaseExtModel):
+    r"""
+    Gordon et al. (2021) Milky Way Average Extinction Curve
+
+    Parameters
+    ----------
+    None
+
+    Raises
+    ------
+    None
+
+    Notes
+    -----
+    From Gordon et al. (2021, ApJ, submitted)
+
+    Example showing the average curve
+
+    .. plot::
+        :include-source:
+
+        import numpy as np
+        import matplotlib.pyplot as plt
+        import astropy.units as u
+
+        from dust_extinction.averages import G21_MWAvg
+
+        fig, ax = plt.subplots()
+
+        # generate the curves and plot them
+        lam = np.logspace(np.log10(1.01), np.log10(31.9), num=1000)
+        x = (1.0/lam)/u.micron
+
+        # define the extinction model
+        ext_model = G21_MWAvg()
+
+        ax.plot(1.0/x,ext_model(x),label='G21_MWAvg')
+        ax.errorbar(1.0/ext_model.obsdata_x_irs, ext_model.obsdata_axav_irs,
+                    yerr=ext_model.obsdata_axav_unc_irs,
+                    fmt='ko', label='obsdata (IRS)')
+        ax.errorbar(1.0/ext_model.obsdata_x_bands, ext_model.obsdata_axav_bands,
+                    yerr=ext_model.obsdata_axav_unc_bands,
+                    fmt='g^', label='obsdata (photometry)')
+
+        ax.set_xlabel(r'$\lambda$ [$\mu m$]')
+        ax.set_ylabel(r'$A(x)/A(V)$')
+
+        ax.set_xscale('log')
+        ax.set_yscale('log')
+
+        ax.legend(loc='best')
+        plt.show()
+    """
+
+    x_range = [1.0 / 32.0, 1.0]
+
+    Rv = 3.17
+
+    def __init__(self, **kwargs):
+
+        # get the tabulated information
+        data_path = pkg_resources.resource_filename("dust_extinction", "data/")
+
+        # GCC09 sigma clipped average of 75 sightlines
+        a = Table.read(data_path + "G21_IRS.dat", format="ascii.commented_header")
+        b = Table.read(data_path + "G21_PHOT.dat", format="ascii.commented_header")
+
+        # IRS range
+        self.obsdata_x_irs = 1.0 / a["wave"].data
+        self.obsdata_axav_irs = a["ext"].data
+        self.obsdata_axav_unc_irs = a["unc"].data
+
+        # Opt/NIR range
+        self.obsdata_x_bands = 1.0 / b["wave"].data
+        self.obsdata_axav_bands = b["ext"].data
+        self.obsdata_axav_unc_bands = b["unc"].data
+
+        # put them together
+        self.obsdata_x = np.concatenate((self.obsdata_x_irs, self.obsdata_x_bands))
+        self.obsdata_axav = np.concatenate(
+            (self.obsdata_axav_irs, self.obsdata_axav_bands)
+        )
+        self.obsdata_axav_unc = np.concatenate(
+            (
+                self.obsdata_axav_unc_irs,
+                self.obsdata_axav_unc_bands,
+            )
+        )
+
+        # accuracy of the observed data based on published table
+        self.obsdata_tolerance = 5e-1
+
+        super().__init__(**kwargs)
+
+    def evaluate(self, in_x):
+        """
+        G21_MWAvg function
+
+        Parameters
+        ----------
+        in_x: float
+           expects either x in units of wavelengths or frequency
+           or assumes wavelengths in wavenumbers [1/micron]
+
+           internally wavenumbers are used
+
+        Returns
+        -------
+        axav: np array (float)
+            A(x)/A(V) extinction curve [mag]
+
+        Raises
+        ------
+        ValueError
+           Input x values outside of defined range
+        """
+        x = _get_x_in_wavenumbers(in_x)
+
+        # check that the wavenumbers are within the defined range
+        _test_valid_x_range(x, self.x_range, self.__class__.__name__)
+
+        # G21 parameters fit to the data using uncs as weights
+        g21_fit = G21(
+            scale=0.366,
+            alpha=1.480,
+            sil1_amp=0.06893,
+            sil1_center=9.865,
+            sil1_fwhm=2.507,
+            sil1_asym=-0.232,
+            sil2_amp=0.02684,
+            sil2_center=19.973,
+            sil2_fwhm=16.989,
+            sil2_asym=-0.273,
+        )
+
+        # return A(x)/A(V)
+        return g21_fit(in_x)
